@@ -4,7 +4,7 @@ package WebService::Avalara::AvaTax::Service::Tax;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.015';     # VERSION
+our $VERSION = '0.016';     # VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -27,13 +27,18 @@ use utf8;
 #pod
 #pod =cut
 
+use Const::Fast;
 use Moo;
 use URI;
 use XML::Compile::SOAP11;
 use XML::Compile::SOAP12;
+use XML::Compile::WSDL11;
+use XML::LibXML::XPathContext;
 use namespace::clean;
 with 'WebService::Avalara::AvaTax::Role::Connection';
 
+const my $AVALARA_NS => 'http://avatax.avalara.com/services';
+
 #pod =attr uri
 #pod
 #pod The L<URI|URI> of the WSDL file used to define the web service.
@@ -71,6 +76,66 @@ has '+port' => ( default => 'TaxSvcSoap' );
 
 has '+service' => ( default => 'TaxSvc' );
 
+#pod =head1 WORKAROUNDS FOR INCORRECT AVALARA RESPONSES
+#pod
+#pod As of this writing the Avalara SOAP API returns responses that are
+#pod inconsistent with the WSDL document provided. Specifically, the C<TaxIncluded>
+#pod and C<GeocodeType> fields in the C<GetTaxResponse> are wrongly placed in their
+#pod sequences of fields. This module adds preprocessing hooks that attempt to
+#pod work around these problems so that the responses may be successfully parsed.
+#pod
+#pod =cut
+
+has '+wsdl' => (
+    default => sub {
+        my $self = shift;
+        XML::Compile::WSDL11->new(
+            $self->user_agent->get( $self->uri )->content,
+            hooks => $self->_make_hooks );
+    },
+);
+
+sub _make_hooks {
+    my $self = shift;
+    my $xpc  = XML::LibXML::XPathContext->new;
+    $xpc->registerNs( ava => $AVALARA_NS );
+    return [
+        {   action => 'READER',
+            type   => "{$AVALARA_NS}TaxLine",
+            before => sub {
+                my $xml = shift->cloneNode(1);
+                my $tax_included = $xpc->findnodes( 'ava:TaxIncluded', $xml );
+                $tax_included->foreach(
+                    sub {
+                        my $parent = $_->parentNode;
+                        $_->unbindNode;
+                        $parent->appendChild($_);
+                    },
+                );
+                return $xml;
+            },
+        },
+        {   action => 'READER',
+            type   => "{$AVALARA_NS}TaxAddress",
+            before => sub {
+                my $xml = shift->cloneNode(1);
+                my $geocode_type = $xpc->findnodes( 'ava:GeocodeType', $xml );
+                $geocode_type->foreach(
+                    sub {
+                        my $parent = $_->parentNode;
+                        my $validate_status
+                            = $xpc->findnodes( 'ava:ValidateStatus', $parent )
+                            ->shift;
+                        $_->unbindNode;
+                        $parent->insertAfter( $_, $validate_status );
+                    },
+                );
+                return $xml;
+            },
+        },
+    ];
+}
+
 1;
 
 __END__
@@ -88,7 +153,7 @@ WebService::Avalara::AvaTax::Service::Tax - Avalara AvaTax tax engine service vi
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -129,6 +194,14 @@ Defaults to C<AddressSvcSoap>.
 The SOAP service name used in the WSDL file at L</uri>.
 Defaults to C<AddressSvc>.
 
+=head1 WORKAROUNDS FOR INCORRECT AVALARA RESPONSES
+
+As of this writing the Avalara SOAP API returns responses that are
+inconsistent with the WSDL document provided. Specifically, the C<TaxIncluded>
+and C<GeocodeType> fields in the C<GetTaxResponse> are wrongly placed in their
+sequences of fields. This module adds preprocessing hooks that attempt to
+work around these problems so that the responses may be successfully parsed.
+
 =head1 SUPPORT
 
 =head2 Perldoc
